/*
** Swishej package Copyright (C) 1999-2001 Christian Werner
** class added by InterRed GmbH 03/2003
**
** This program and library is free software; you can redistribute it and/or
** modify it under the terms of the GNU (Library) General Public License
** as published by the Free Software Foundation; either version 2
** of the License, or any later version.
**
** This program is distributed in the hope that it will be useful,
** but WITHOUT ANY WARRANTY; without even the implied warranty of
** MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
** GNU (Library) General Public License for more details.
**
** You should have received a copy of the GNU (Library) General Public License
** along with this program; if not, write to the Free Software
** Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
*/

package swishej;

import java.applet.*;
import java.net.*;

public class JSSearchApplet extends Applet {
  private String inputString = "";
  private final static int STATUS_LOADING_IDX = 0;
  private final static int STATUS_READY = 1;
  private final static int STATUS_LOAD_ERR = 2;
  private int status = 0;
  private IndexFile indexFile;
  private URL indexFileURL;
  private SortResultList sortResultList = null;


  public JSSearchApplet(){
  }

  public void init(){
    try {
      indexFileURL = new URL(getDocumentBase(),
                          getParameter("indexfile"));
    } catch (MalformedURLException e) {
      System.out.println("bad URL for indexfile:\n" + e);
    }
  }

  public void start(){
    if (this.indexFile == null) {
      this.status = STATUS_LOADING_IDX;
      try {
        this.indexFile = Search.loadindex(indexFileURL);
      } catch (Exception e) {
        System.out.println("Error loading index:\n" + e);
      }
      this.status = (this.indexFile != null ? STATUS_READY : STATUS_LOAD_ERR);
//      System.out.println("Index " + (this.indexFile == null ? "not " : "") + "loaded.");
    }
  }

  public String getInput(){
    return this.inputString;
  }


  public int getResultCount(){
    if(this.sortResultList != null)
      return this.sortResultList.getResultCount();
    else
      return 0;
  }

  public String getResultTitle(int index){
    // Werte in resultInfos-Array: 0. file name, 1. title, 2. file size
    if(this.sortResultList != null)
      return this.sortResultList.getResultInfos(index)[1];
    else
      return "";
  }

  public String getResultFilename(int index){
    if(this.sortResultList != null)
      return this.sortResultList.getResultInfos(index)[0];
    else
      return "";
  }

  public void doSearch(String input){
    this.inputString = input;
    if(isReady() && input != null && input.length()>0){
      this.sortResultList = SearchImpl.getSortResult(indexFile, input, -1, -1, getDocumentBase());
    }
  }

  public int getStatus(){
    return this.status;
  }

  public boolean isReady(){
    return this.status == STATUS_READY;
  }

/**
  * Applet info blurks.
  * @return string with copy.*t information.
  */
  public String getAppletInfo() {
       return "SWISH-E Search Applet\n" +
    "Copyright (C) 1999-2001 Christian Werner\n\n" +
    "This program and library is free software; you can\n" +
    "redistribute it and/or modify it under the terms of\n" +
    "the GNU (Library) General Public License as published\n" +
    "by the Free Software Foundation; either version 2 of\n" +
    "the License, or any later version.\n\n" +
    "This program is distributed in the hope that it will be\n" +
    "useful, but WITHOUT ANY WARRANTY; without even the\n" +
    "implied warranty of MERCHANTABILITY or FITNESS FOR A\n" +
    "PARTICULAR PURPOSE. See the GNU (Library) General Public\n" +
    "License for more details.\n\n" +
    "You should have received a copy of the GNU (Library)\n" +
    "General Public License along with this program; if not,\n" +
    "write to the Free Software Foundation, Inc., 59 Temple\n" +
     "Place - Suite 330, Boston, MA  02111-1307, USA.\n";
  }

    /**
     * Return information about applet parameters.
     * @return String array with parameter description.
     */
  public String[][] getParameterInfo() {
      String[][] info = {
//          {"resultframe", "string", "browser frame for result"},
          {"indexfile", "url", "swish-e index file"}
//          {"searchbutton", "string", "text for search button"},
//          {"wordsbutton", "string", "text for words button"},
//          {"clearbutton", "string", "text for clear button"},
//          {"helpbutton", "string", "text for help button"},
//          {"kwlabel", "string", "text for keyword entry label"},
//          {"charmap", "string", "character mapping for result pages"}
      };
    return info;
  }

}