/*
** Copyright (C) 1999-2001 Christian Werner
**
** This program and library is free software; you can redistribute it and/or
** modify it under the terms of the GNU (Library) General Public License
** as published by the Free Software Foundation; either version 2
** of the License, or any later version.
**
** This program is distributed in the hope that it will be useful,
** but WITHOUT ANY WARRANTY; without even the implied warranty of
** MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
** GNU (Library) General Public License for more details.
**
** You should have received a copy of the GNU (Library) General Public License
** along with this program; if not, write to the Free Software
** Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
*/

package swishej;

import java.net.*;
import java.io.*;

/**
 * Functions for making a document preview.
 */

class Preview {
    /**
     * Make a document preview from an URL. 
     * @param base base URL for document
     * @param file file name relative to base URL
     * @return string representing document preview, length is less than
     * 320 characters, or null if the URL load failed.
     */
    static String preview(URL base, String file) {
        byte b[] = null;
        try {
	    URL url = new URL(base, file);
	    URLConnection uc = url.openConnection();
	    int length = uc.getContentLength();
	    if (length <= 0) {
	        return null;
	    }
	    if (length > 2000) {
	        length = 2000;
	    }
	    b = new byte[length];
	    int got = 0;
	    while (got != length) {
	        int nread = uc.getInputStream().read(b, got, length - got);
		if (nread == -1) {
		    return null;
		}
		got += nread;
	    }
	} catch (Exception e) {
	    return null;
	}
	/*
	 * Eat all potential HTML tags "<..>", all
	 * char entities "&..;" and newlines
	 */
	StringBuffer sb = new StringBuffer();
	for (int i = 0; i < b.length; i++) {
	    char c = (char) (b[i] & 0xFF);
	    if (c == '<') {
	        ++i;
		if (i < b.length - 2) {
		    char c1, c2, c3;
		    c1 = (char) (b[i] & 0xFF);
		    c2 = (char) (b[i + 1] & 0xFF);
		    c3 = (char) (b[i + 2] & 0xFF);
		    if (c1 == '!' && c2 == '-' && c3 == '-') {
			i += 2;
			int endf = 0;
			while (true) {
			    if (i >= b.length) {
				break;
			    }
			    c = (char) (b[i] & 0xFF);
			    if (endf < 2 && c == '-') {
				endf++;
			    } else if (endf >= 2 && c == '>') {
				break;
			    } else {
				endf = 0;
			    }
			    ++i;
			}
		    }
		}
		while (i < b.length) {
		    c = (char) (b[i] & 0xFF);
		    if (c == '>') {
		        break;
		    }
		    ++i;
		}
		while (i < b.length) {
		    c = (char) (b[i] & 0xFF);
		    if (c != '>') {
		        break;
		    }
		    ++i;
		}
		--i;
		continue;
	    } else if (c == '&') {
	        ++i;
		while (i < b.length) {
		    c = (char) (b[i] & 0xFF);
		    if (c == ';') {
		        break;
		    }
		    ++i;
		}
		continue;
	    } else if (c == '"') {
	        sb.append("\\\"");
	    } else if (c == '\n' || c == '\r') {
	        sb.append(" ");
	    } else { 
	        sb.append(c);
	    }
	}
	String r = sb.toString();
	if (r.length() > 320) {
	    r = r.substring(0, 320);
	}
	return r;
    }
}
