/*
** Copyright (C) 1999 Christian Werner
**
** This program and library is free software; you can redistribute it and/or
** modify it under the terms of the GNU (Library) General Public License
** as published by the Free Software Foundation; either version 2
** of the License, or any later version.
**
** This program is distributed in the hope that it will be useful,
** but WITHOUT ANY WARRANTY; without even the implied warranty of
** MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
** GNU (Library) General Public License for more details.
**
** You should have received a copy of the GNU (Library) General Public License
** along with this program; if not, write to the Free Software
** Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
*/

package swishej;

import java.io.IOException;

/**
 * Interface for reading a SWISH-E index file.
 * @see swishej.FReader
 * @see swishej.UReader
 */

interface Reader {
    /**
     * Read an array of bytes.
     * @param b byte array to be filled by the read
     * @return number of bytes read
     * @exception IOException if an error occurred
     */
    public int read(byte[] b) throws IOException;

    /**
     * Seek to file position.
     * @param pos position measured from begin of file, must be positive
     * @exception IOException if an error occurred
     */
    public void seek(long pos) throws IOException;

    /**
     * Retrieve current file position
     * @return current file position
     */
    public long tell();
}
