/*
** Copyright (C) 1999 Christian Werner
**
** This program and library is free software; you can redistribute it and/or
** modify it under the terms of the GNU (Library) General Public License
** as published by the Free Software Foundation; either version 2
** of the License, or any later version.
**
** This program is distributed in the hope that it will be useful,
** but WITHOUT ANY WARRANTY; without even the implied warranty of
** MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
** GNU (Library) General Public License for more details.
**
** You should have received a copy of the GNU (Library) General Public License
** along with this program; if not, write to the Free Software
** Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
*/

package swishej;

/**
 * Node in linked list of strings (StrList)
 * @see swishej.StrList
 */

class StrNode {
    /**
     * Successor or null.
     */
    StrNode next;

    /**
     * String of this node.
     */
    String string;

    /**
     * Create node given string. Successor is null.
     * @param str String
     */
    StrNode(String str) {
        string = new String(str);
	next = null;
    }
}

/**
 * Ordered (linked) list of strings.
 */

class StrList {
    /**
     * First node in list.
     */
    StrNode firstN;

    /**
     * Last node in list.
     */
    StrNode lastN;

    /**
     * Next node while traversing list.
     */
    StrNode searchN;

    /**
     * Create new empty string list.
     */
    StrList() {
        firstN = null;
	lastN = null;
	searchN = null;
    }

    /**
     * Remove first string from list, terminate traversal.
     */
    void rest() {
        if (firstN != null) {
	    firstN = firstN.next;
	} else {
	    lastN = null;
	}
	if (firstN == null) {
	    lastN = null;
	}
	searchN = null;
    }

    /**
     * Is the string list empty ?
     * @return true if list is empty, false otherwise
     */
    boolean empty() {
        return firstN == null;
    }

    /**
     * Add string to end of string list.
     * @param string String to be added.
     */
    void add(String string) {
        StrNode node = new StrNode(string);
	if (lastN == null) {
	    firstN = node;
	} else {
	    lastN.next = node;
	}
	lastN = node; 
    }

    /**
     * Start string list traversal, retrieve first string in list.
     * @return First string in list
     */
    String first() {
        searchN = firstN;
	if (searchN != null) {
	    return searchN.string;
	}
	return null;
    }

    /**
     * Continue string list traversal, retrieve next string in list.
     * @return Next string in list
     */
    String next() {
        if (searchN != null) {
	    searchN = searchN.next;
	}
	if (searchN != null) {
	    return searchN.string;
	}
	return null;
    }

    /**
     * Retrieve next string in list without advancing in traversal.
     * @return Next string in list
     */
    String succ() {
        if (searchN != null && searchN.next != null) {
	    return searchN.next.string;
	}
	return null;
    }
}
